@@ -483,6 +483,33 @@ class Agent(Insight, Channel, Catalog, Dataset):
     }
     '''
 
+    def check_dataset_columns(self, dataframe: pd.DataFrame, dataset_id):
+
+        body = dataframe.to_dict(orient="record")
+
+        url = self._base_url_askdata + '/smartdataset/datasets/'+dataset_id+'/sdk/check'
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        logging.info("AUTH URL {}".format(url))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+        response = s.post(url=url, json=body, headers=headers)
+        response.raise_for_status()
+        r = response.json()
+
+        if(r["hasDifference"]):
+            for differece in r["differences"]:
+                logging.info("Column {} is being {}".format(differece["columnName"], differece["differenceType"]))
+        return r["hasDifference"]
+
+
     def create_or_replace_dataset(self, dataframe: pd.DataFrame, dataset_name: str, slug: str, icon_url=None,
                                   settings: dict = None):
         # Check if dataset exists
@@ -496,6 +523,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
             # If not exists create a new one
             self.create_dataset(dataframe, dataset_name, slug, icon_url, settings)
 
+
     def delete_dataset(self, slug='', dataset_id=''):
 
         if slug != '':
