@@ -2,10 +2,6 @@ import requests
 import yaml
 import os
 import logging
-from askdata.insight import Insight
-from askdata.channel import Channel
-from askdata.catalog import Catalog
-from askdata.dataset import Dataset
 import pandas as pd
 from requests.adapters import HTTPAdapter
 from urllib3.util.retry import Retry
@@ -1173,7 +1169,7 @@ class Insight_Definition:
 
         if card_name == "":
             card_name = "Copy of " + self.name
-        url = "https://api-dev.askdata.com/smartinsight/definitions/1dae1fcd-d96f-4c9f-ba7e-cdab6b34ff1d/clone"
+        url = self.smart_insight_url+"/definitions/"+self.definition_id+"/clone"
         body = {
             "agentId": self.agent_id,
             "name": card_name,
