@@ -40,6 +40,7 @@ class Field:
 
 class SQLOperator(Enum):
     EQ = auto()
+    NOT_EQ = auto()
     GOE = auto()
     GT = auto()
     LOE = auto()
@@ -54,12 +55,29 @@ class BooleanOperator(Enum):
     OR = auto()
 
 
+class TimePeriodOperator(Enum):
+    FROM = auto()
+    TO = auto()
+    INTERVAL = auto()
+
+
+class CTDOperator(Enum):
+    CURR = auto()
+    PREV = auto()
+    PREV_BFR = auto()
+    NEXT = auto()
+    NEXT_AFT = auto()
+    BFR = auto()
+    AFT = auto()
+
+
 @dataclass
 class Condition:
     field: Field
-    operator: Union[SQLOperator, str]
-    value: List[Union[float, str]]
+    operator: Union[SQLOperator, CTDOperator, TimePeriodOperator, str]
+    value: Optional[List[Union[float, str]]] = None
     type: Optional[str] = None
+    window: Optional[str] = None
 
     def __repr__(self):
         vars = []
@@ -124,11 +142,21 @@ class Component:
     queryId: str
 
 
+@dataclass
+class QueryComponent(Component):
+    category: str
+
+
 @dataclass
 class ChartComponent(Component):
     chartType: str
 
 
+@dataclass
+class MapComponent(Component):
+    mapType: str
+
+
 @dataclass
 class From:
     dataset: str
@@ -207,7 +235,7 @@ class Query:
 @dataclass
 class SmartQuery:
     queries: List[Query]
-    components: Optional[List[Union[ChartComponent, Component]]] = None
+    components: Optional[List[Union[ChartComponent, MapComponent, QueryComponent, Component]]] = None
     javascript: Optional[List[str]] = None
 
     @staticmethod
