@@ -12,11 +12,19 @@ if __name__ == '__main__':
     condition2 = Condition(field3, "LOE", ["{{timePeriod.B}}"])
     condition3 = Condition(field1, "EQ", [2000])
     sorting1 = Sorting("{{measure.A}}", SQLSorting.DESC)
+    component = ChartComponent(type='chart', queryId="0", chartType='LINE')
     query1 = Query(fields=[field1, field2, field3], datasets=[from1, from2, from3], where=[condition1, condition2, condition3],
                    orderBy=[sorting1], limit=10)
-    smartquery = SmartQuery([query1])
-    dump = jsons.dump(smartquery)
+    smartquery = SmartQuery(id='0', queries=[query1], components=[component])
+    dump = jsons.dumps(smartquery)
     print(dump)
-    smartquery = jsons.load(dump, SmartQuery)
+    smartquery = jsons.loads(dump, SmartQuery)
+    print(jsons.dumps(smartquery))
     print(smartquery)
     print(smartquery.queries[0].to_sql())
+    print("ORIGINAL JSON: ", dump)
+    compressed_json = SmartQuery.compress(dump)
+    print("COMPRESSED JSON: ", compressed_json)
+    decompressed_json = SmartQuery.decompress(compressed_json)
+    print("DECOMPRESSED JSON: ", decompressed_json)
+    print(str(dump) == decompressed_json)
